@@ -10,6 +10,8 @@ try:
 except ImportError:
     logging.info("Could not import redis, RedisDatastore is not available")
 
+# 32 and 64 bit values work differently between the two datastores!
+
 
 class DictDatastore:
     def __init__(self):
@@ -22,9 +24,9 @@ class DictDatastore:
         self.datadict = dict(self.empty_datadict)
         logger.debug("Initialized empty DictDatastore")
 
-    def read(self, object_reference, first_address, quantity_of_records):
+    def read(self, object_reference, first_address, number_of_records):
         data = []
-        for address in range(first_address, first_address + quantity_of_records):
+        for address in range(first_address, first_address + number_of_records):
             data.append(self.datadict[object_reference][address])
         return data
 
@@ -51,11 +53,13 @@ class DictDatastore:
 
 
 class RedisDatastore:
-    def __init__(self, modbus_address_map={}, host="localhost", port=6379, db=0):
+    def __init__(
+        self, modbus_address_map={}, redis_host="localhost", redis_port=6379, redis_db=0
+    ):
 
-        self.host = host
-        self.port = port
-        self.db = db
+        self.host = redis_host
+        self.port = redis_port
+        self.db = redis_db
         self.modbus_address_map = modbus_address_map
         self.r = None
         self._verify_modbus_address_map()
@@ -84,9 +88,10 @@ class RedisDatastore:
             if std_key not in self.modbus_address_map:
                 self.modbus_address_map[std_key] = {}
 
-    # def set_initial_values(self):
-    # TODO:
-    #     self.modbus_address_map
+    def apply_initial_values(self):
+        for object_reference, addresses in self.modbus_address_map.items():
+            for address, props in addresses.items():
+                self.r.set(props["key"], props["initial_value"])
 
     def print_address_map(self):
         print(self.modbus_address_map)
@@ -99,9 +104,9 @@ class RedisDatastore:
                     f"\tAddress: {address} -> {props['key']} : {self.r.get(props['key'])}"
                 )
 
-    def read(self, object_reference, first_address, quantity_of_records):
+    def read(self, object_reference, first_address, number_of_records):
         data = []
-        for address in range(first_address, first_address + quantity_of_records):
+        for address in range(first_address, first_address + number_of_records):
             address_properties = self.modbus_address_map[object_reference][str(address)]
             key = address_properties["key"]
 
